@@ -172,7 +172,7 @@ def ProfileMiddleware(application):
 
                     from cgi import escape
                     splitor = """\n<hr style="border:0;border-bottom:1px dashed;margin:20px 0">\n"""
-                    so = escape(splitor.join(i.strip() for i in so))
+                    so = splitor.join(escape(i.strip()) for i in so)
                     so = """<pre style="clear:both;padding:1em;background:#ffffde;color:#033">\n%s\n</pre>"""%so
                     result = "%s %s"%(result, so)
                 return result
