@@ -24,6 +24,6 @@ def get_db_by_table(table_name):
     return SQLSTORE.get_db_by_table(table_name)
 connection.get_db_by_table = get_db_by_table
 
-from sqlbean.shortcut import Query, mc, MMcCache, McCache, ForeignKey, OneToMany, Model, McModel
+from sqlbean.shortcut import Query, mc, McCacheM, McCache, ForeignKey, OneToMany, Model, McModel
 
 
