@@ -41,10 +41,21 @@ def render_para_func(func):
 
 
 def render_func(func):
-    template = "%s/%s.htm"%(
-        func.__module__[FUNC_MODULE_PREFIX_LEN:].replace(".", "/"),
-        func.__name__
-    )
+    if type(func) is str:
+        return lambda f:_render_func(f,func) 
+    else:
+        template = "/%s/%s.htm"%(
+            func.__module__[FUNC_MODULE_PREFIX_LEN:].replace(".", "/"),
+            func.__name__
+        )
+        return _render_func(func,template)
+
+def _render_func(func,template):
+    if not template.startswith("/"):
+        template = "%s/%s"%(
+            func.__module__[FUNC_MODULE_PREFIX_LEN:].replace(".", "/"),
+            template
+        )
     def  _wrap_func(func, *args, **kwds):
         G = Render(template)
         request = get_request()
