@@ -60,7 +60,11 @@ def wrap_func(func):
     return f
 
 def route_render_func(func):
-    return _ROUTE(render_func(func))
+    if type(func) is str:
+        w = render_func(func)
+        return lambda f:_ROUTE(w(f))
+    else:
+        return _ROUTE(render_func(func))
 
 def route_render_doc(func):
     return _ROUTE(render_doc(func))
